.. _scan_command:

Scan Command
============

Use this command to scan for GRIB files

.. argparse::
    :module: anemoi.datasets.__main__
    :func: create_parser
    :prog: anemoi-datasets
    :path: scan
